=================
HEPData Converter
=================


.. image:: https://img.shields.io/travis/HEPData/hepdata-converter.svg
   :target: https://travis-ci.org/HEPData/hepdata-converter
   :alt: Travis Status

.. image:: https://coveralls.io/repos/github/HEPData/hepdata-converter/badge.svg?branch=master
   :target: https://coveralls.io/github/HEPData/hepdata-converter?branch=master
   :alt: Coveralls Status

.. image:: https://img.shields.io/github/license/HEPData/hepdata-converter.svg
   :target: https://github.com/HEPData/hepdata-converter/blob/master/LICENSE.txt
   :alt: License

.. image:: https://img.shields.io/github/release/hepdata/hepdata-converter.svg?maxAge=2592000
   :target: https://github.com/HEPData/hepdata-converter/releases
   :alt: GitHub Releases

.. image:: https://img.shields.io/github/issues/hepdata/hepdata-converter.svg?maxAge=2592000
   :target: https://github.com/HEPData/hepdata-converter/issues
   :alt: GitHub Issues

.. image:: https://readthedocs.org/projects/hepdata-converter/badge/?version=latest
   :target: http://hepdata-converter.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status


This Python library provides support for converting:

* Old HepData input format (`sample <https://github.com/HEPData/hepdata-submission/blob/master/examples/oldhepdata/sample.oldhepdata>`_) to `YAML <https://github.com/HEPData/hepdata-submission>`_
* `YAML <https://github.com/HEPData/hepdata-submission>`_ to:

  * `ROOT <https://root.cern.ch>`_
  * `YODA <https://yoda.hepforge.org>`_
  * `CSV <https://en.wikipedia.org/wiki/Comma-separated_values>`_

Documentation: http://hepdata-converter.readthedocs.io